#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <pwd.h>
#include <gnome.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#include "var.h"
#include "gtudb.h"
#include "mw.h"
#include "pw.h"
#include "dw.h"
#include "bw.h"
#include "sw.h"
#include "fdw.h"
#include "idbw.h"



/*
 * MainWindow -> Menu -> Zakoncz
 * Konczy prace programu
 */
void on_mw_menu_zakoncz1_activate (GtkMenuItem* menuitem, gpointer user_data)
{
	on_main_window_delete_event (NULL, NULL, NULL);
    gtk_main_quit();
}


/*
 * MainWindow
 * Konczy prace programu, przy zamknieciu okna
 */
void on_main_window_destroy (GtkObject*object, gpointer user_data)
{
    gtk_main_quit();
}


/*
 * MainWindow
 * Funkcja wywolowana przy starcie programu
 */
void on_main_window_show (GtkWidget *widget, gpointer user_data)
{
	mw_show (widget);
}


/*
 * MainWindow -> Calendar
 * Funkcja wywolywana przy wybraniu dnia w kalendarzu
 */
void on_mw_calendar_day_selected (GtkCalendar *calendar, gpointer user_data)
{
	// Pobieramy date z kalendarza
	type_date tmp;
	gtk_calendar_get_date (calendar, &tmp.year, &tmp.month, &tmp.day);
	tmp.month++;
	
	// Wczytujemy wpis
	mw_edit_entry (tmp, TRUE);
}


/*
 * MainWindow -> mw_marks_clist
 * Funkcja wywolywana po wybraniu wiersza w liscie przedmiotow i ocen
 */
void on_mw_marks_clist_select_row (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer user_data)
{
	mw_marks_clist_rowselected = row;
	
	GtkWidget *mw_marks_delete_btn = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_marks_delete_btn");
	gtk_widget_set_sensitive (GTK_WIDGET (mw_marks_delete_btn), TRUE);
	
	GtkWidget *mw_marks_save_btn = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_marks_save_btn");
	gtk_widget_set_sensitive (GTK_WIDGET (mw_marks_save_btn), TRUE);
}


/*
 * MainWindow -> mw_marks_clist
 * Funkcja wywolywana, gdy zaden wiersz listy przedmiotow nie jest zaznaczony
 */
void on_mw_marks_clist_unselect_row (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer user_data)
{
	mw_marks_clist_rowselected = -1;
	
	GtkWidget *mw_marks_delete_btn = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_marks_delete_btn");
	gtk_widget_set_sensitive (GTK_WIDGET (mw_marks_delete_btn), FALSE);
	
	GtkWidget *mw_marks_save_btn = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_marks_save_btn");
	gtk_widget_set_sensitive (GTK_WIDGET (mw_marks_save_btn), FALSE);
}


/*
 * MainWindow -> mw_marks_add_btn
 * Funkcja wywolywana po kliknieciu przycisku dodawania przedmiotow
 */
void on_mw_marks_add_btn_clicked(GtkButton * button, gpointer user_data)
{
	mw_marks_clist_rowselected = -1;
	
	mwes_widget = create_main_window_edit_subject ();
	gtk_widget_show (GTK_WIDGET (mwes_widget));
}


/*
 * MainWindow -> mw_marks_delete_btn
 * Funkcja wywolywana po kliknieciu przycisku usuwania przedmiotow
 */
void on_mw_marks_delete_btn_clicked(GtkButton * button, gpointer user_data)
{
	if (mw_marks_clist_rowselected >= 0)
		mw_marks_clist_remove (mw_marks_clist_rowselected);
}


/*
 * MainWindow -> mw_marks_save_btn
 * Funkcja wywolywana po kliknieciu przycisku modyfikowania przedmiotu
 */
void on_mw_marks_save_btn_clicked (GtkButton *button, gpointer user_data)
{
	if (mw_marks_clist_rowselected >= 0) {
		mwes_widget = create_main_window_edit_subject ();
		mwes_marks_edit (mw_marks_clist_rowselected);
		gtk_widget_show (GTK_WIDGET (mwes_widget));
	}
}


/*
 * MainWindow -> menu -> informacje o...
 * Otwiera okno Informacje o... (AboutWindow)
 */
void on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	GtkWidget *about_window = create_about_window ();
	gtk_widget_show (GTK_WIDGET (about_window));
}


/*
 * ImportDBWindow -> idbw_btn_cancel
 * Funkcja wywolywana po kliknieciu przycisku anuluj
 */
void on_idbw_btn_cancel_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (GTK_WIDGET (idbw_widget));
	gnome_app_message (GNOME_APP (mw_widget), _("Wykryto i zaimportowano dane ze starszej wersji programu.\n\nZalecanie jest wpisanie godzin w planie lekcji. Aby to zrobic wybierz z menu Ustawienia opcje Plan lekcji."));
}


/*
 * MainWindow
 * Funkcja wywolywana przy usuwaniu glownego okna (MainWindow)
 */
gboolean on_main_window_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	mw_edit_entry (entry_date, TRUE);
	gtudb_write ();
	gtudb_settings_write ();
	
	return FALSE;
}


/*
 * PlanWindow -> pw_cancel_btn
 * Funkcja wywolywana po kliknieciu na przycisk pw_cancel_btn
 */
void on_pw_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (pw_widget);
}


/*
 * PlanWindow -> pw_ok_btn
 * Funkcja wywolywana po kliknieciu na przycisk pw_ok_btn
 */
void on_pw_ok_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtudb_plan_write (); // zapisujemy plan lekcji
	gtudb_plan_read ();  // ponownie wczytujemy plan lekcji
	
	gtk_widget_hide (pw_widget); // ...i zamykamy okno
}



/*
 * edit_plan_window -> epw_cancel_btn
 * Funkcja wywolywana po kliknieciu na przycisk epw_cancel_btn
 */
void on_epw_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (epw_widget);
}


/*
 * edit_plan_window -> epw_ok_btn
 * Funkcja wywolywana po kliknieciu na przycisk epw_ok_btn
 */
void on_epw_ok_btn_clicked (GtkButton *button, gpointer user_data)
{
	// zapisujemy dane
	pw_epw_get_subjects ();
	
	// odswiezamy plan lekcji !
	pw_load_subjects ();
	
	// ukrywamy okno
	gtk_widget_hide (epw_widget);
}


/*
 * plan_window -> pw_edit_d0
 * Funkcja wywolywana po kliknieciu na przycisk pw_edit_d0
 */
void on_pw_edit_d0_btn_clicked (GtkButton *button, gpointer user_data)
{
	ephw_widget = create_edit_plan_hours_window ();
	
	pw_ephw_load_hours ();
	gtk_widget_show    (GTK_WIDGET (ephw_widget));
}


/*
 * plan_window -> pw_edit_d1
 * Funkcja wywolywana po kliknieciu na przycisk pw_edit_d1
 */
void on_pw_edit_d1_btn_clicked (GtkButton *button, gpointer user_data)
{
	epw_widget  = create_edit_plan_window ();
	
	pw_epw_edit_day = 1;
	pw_epw_load_subjects (1);
	gtk_widget_show (GTK_WIDGET (epw_widget));
}


/*
 * plan_window -> pw_edit_d2
 * Funkcja wywolywana po kliknieciu na przycisk pw_edit_d2
 */
void on_pw_edit_d2_btn_clicked (GtkButton *button, gpointer user_data)
{
	epw_widget  = create_edit_plan_window ();
	
	pw_epw_edit_day = 2;
	pw_epw_load_subjects (2);
	gtk_widget_show (GTK_WIDGET (epw_widget));
}


/*
 * plan_window -> pw_edit_d3
 * Funkcja wywolywana po kliknieciu na przycisk pw_edit_d3
 */
void on_pw_edit_d3_btn_clicked (GtkButton *button, gpointer user_data)
{
	epw_widget  = create_edit_plan_window ();
	
	pw_epw_edit_day = 3;
	pw_epw_load_subjects (3);
	gtk_widget_show (GTK_WIDGET (epw_widget));
}


/*
 * plan_window -> pw_edit_d4
 * Funkcja wywolywana po kliknieciu na przycisk pw_edit_d4
 */
void on_pw_edit_d4_btn_clicked (GtkButton *button, gpointer user_data)
{
	epw_widget  = create_edit_plan_window ();
	
	pw_epw_edit_day = 4;
	pw_epw_load_subjects (4);
	gtk_widget_show (GTK_WIDGET (epw_widget));
}


/*
 * plan_window -> pw_edit_d5
 * Funkcja wywolywana po kliknieciu na przycisk pw_edit_d5
 */
void on_pw_edit_d5_btn_clicked (GtkButton *button, gpointer user_data)
{
	epw_widget  = create_edit_plan_window ();
	
	pw_epw_edit_day = 5;
	pw_epw_load_subjects (5);
	gtk_widget_show (GTK_WIDGET (epw_widget));
}


/*
 * plan_window -> pw_edit_d6
 * Funkcja wywolywana po kliknieciu na przycisk pw_edit_d6
 */
void on_pw_edit_d6_btn_clicked (GtkButton *button, gpointer user_data)
{
	epw_widget  = create_edit_plan_window ();
	
	pw_epw_edit_day = 6;
	pw_epw_load_subjects (6);
	gtk_widget_show (GTK_WIDGET (epw_widget));
}


/*
 * edit_plan_window -> epw_add_btn
 * Funkcja wywolywana po kliknieciu na przycisk epw_add_btn
 * Wstawia pozycje do listy przedmiotow (w edytowanym dniu)
 */
void on_epw_add_btn_clicked (GtkButton *button, gpointer user_data)
{
	GtkWidget *epw_subject_entry = (gpointer) lookup_widget (GTK_WIDGET (epw_widget), "epw_subject_entry");
	GtkWidget *epw_time_clist    = (gpointer) lookup_widget (GTK_WIDGET (epw_widget), "epw_time_clist");
	gchar     *tmp;
	
	gtk_clist_get_text (GTK_CLIST (epw_time_clist), pw_epw_select_hour, 0, &tmp);
	pw_epw_add_subject ((gchar *) gtk_entry_get_text (GTK_ENTRY (epw_subject_entry)), g_strdup (tmp));
	pw_epw_time_clist_remove (pw_epw_select_hour);
}


/*
 * MainWindow->Ustawienia->Plan lekcji
 * Otwiera okno PlanWindow
 */
void on_plan_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	pw_show ();
}


/*
 * edit_plan_window -> epw_subjects_clist
 * Funkcja wywolywana odznaczeniu dowolnej pozycji w liscie epw_subjects_clist
 */
void on_epw_subjects_clist_select_row (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer user_data)
{
	GtkWidget *epw_remove_btn = (gpointer) lookup_widget (GTK_WIDGET (epw_widget), "epw_remove_btn");
	gtk_widget_set_sensitive (GTK_WIDGET (epw_remove_btn), TRUE);
	
	pw_epw_select_subject = row;
}


/*
 * edit_plan_window -> epw_subjects_clist
 * Funkcja wywolywana zaznaczeniu dowolnej pozycji w liscie epw_subjects_clist
 */
void on_epw_subjects_clist_unselect_row (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer user_data)
{
	GtkWidget *epw_remove_btn = (gpointer) lookup_widget (GTK_WIDGET (epw_widget), "epw_remove_btn");
	gtk_widget_set_sensitive (GTK_WIDGET (epw_remove_btn), FALSE);
	
	pw_ephw_select_hour = -1;
}


/*
 * edit_plan_hours_window -> ephw_add_hour_btn
 * Funkcja wywolywana kliknieciu na przycisk ephw_remove_hour_btn
 */
void on_ephw_add_hour_btn_clicked (GtkButton *button, gpointer user_data)
{
	GtkWidget *ephw_hour_entry = (gpointer) lookup_widget (GTK_WIDGET (ephw_widget), "ephw_hour_entry");
	
	pw_ephw_add_hour ((gchar *) gtk_entry_get_text (GTK_ENTRY (ephw_hour_entry)));
	gtk_entry_set_text (GTK_ENTRY (ephw_hour_entry), "");
}


/*
 * edit_plan_hours_window -> ephw_remove_hour_btn
 * Funkcja wywolywana kliknieciu na przycisk ephw_remove_hour_btn
 */
void on_ephw_remove_hour_btn_clicked (GtkButton *button, gpointer user_data)
{
	pw_ephw_remove_hour (pw_ephw_select_hour);
}


/*
 * edit_plan_hours_window -> ephw_hours_clist
 * Funkcja wywolywana po zaznaczeniu dowolnej pozycji w liscie epwh_hours_clist
 */
void on_ephw_hours_clist_select_row (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer user_data)
{
	GtkWidget *ephw_remove_hour_btn = (gpointer) lookup_widget (GTK_WIDGET (ephw_widget), "ephw_remove_hour_btn");
	gtk_widget_set_sensitive (GTK_WIDGET (ephw_remove_hour_btn), TRUE);
	
	pw_ephw_select_hour = row;
}


/*
 * edit_plan_hours_window -> ephw_hours_clist
 * Funkcja wywolywana po odnaczeniu dowolnej pozycji w liscie epwh_hours_clist
 */
void on_ephw_hours_clist_unselect_row (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer user_data)
{
	GtkWidget *ephw_remove_hour_btn = (gpointer) lookup_widget (GTK_WIDGET (ephw_widget), "ephw_remove_hour_btn");
	gtk_widget_set_sensitive (GTK_WIDGET (ephw_remove_hour_btn), FALSE);
	
	pw_ephw_select_hour = -1;
}


/*
 * edit_plan_hours_window -> ephw_cancel_btn
 * Funkcja wywolywana po kliknieciu na przycisk ephw_cancel_btn
 */
void on_ephw_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	if (g_slist_length (gtudb_plan_list [0]) == 0)
		pw_disable_buttons ();
	else
		pw_enable_buttons ();
	
	gtk_widget_hide (GTK_WIDGET (ephw_widget));
}


/*
 * edit_plan_hours_window -> ephw_ok_btn
 * Funkcja wywolywana po kliknieciu na przycisk ephw_ok_btn
 * modyfikuje godziny i zamyka okno
 */
void on_ephw_ok_btn_clicked (GtkButton *button, gpointer user_data)
{
	// zapisujemy godziny
	pw_ephw_get_hours ();
	
	// odswiezamy plan lekcji !
	pw_load_subjects ();
	
	// przyciski w oknie planu lekcji
	if (g_slist_length (gtudb_plan_list [0]) == 0)
		pw_disable_buttons ();
	else
		pw_enable_buttons ();
	
	// ukrywamy okno
	gtk_widget_hide (GTK_WIDGET (ephw_widget));
}


/*
 * edit_plan_window -> epw_remove_btn
 * Funkcja wywolywana po kliknieciu na przycisk epw_remove_btn
 * usuwa zaznaczony na liscie przedmiot
 */
void on_epw_remove_btn_clicked (GtkButton *button, gpointer user_data)
{
	pw_epw_remove_subject (pw_epw_select_subject);
}


/*
 * edit_plan_window -> epw_time_clist
 * Funkcja wywolywana po wybraniu dowolnego elementu listy epw_time_clist
 */	
void on_epw_time_clist_select_row (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer user_data)
{
	GtkWidget *epw_add_btn       = (gpointer) lookup_widget (GTK_WIDGET (epw_widget), "epw_add_btn");
	GtkWidget *epw_subject_entry = (gpointer) lookup_widget (GTK_WIDGET (epw_widget), "epw_subject_entry");
	
	pw_epw_select_hour = row;
	
	if ((pw_epw_select_hour >= 0) && (strlen (gtk_entry_get_text (GTK_ENTRY (epw_subject_entry))) > 0))
		gtk_widget_set_sensitive (GTK_WIDGET (epw_add_btn), TRUE);
	else
		gtk_widget_set_sensitive (GTK_WIDGET (epw_add_btn), FALSE);
}


/*
 * edit_plan_window -> epw_time_clist
 * Funkcja wywolywana po odznaczeniu dowolnego elementru listy epw_time_clist
 */	
void on_epw_time_clist_unselect_row (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer user_data)
{
	pw_epw_select_hour = -1;
}


/*
 * edit_plan_window -> epw_subject_entry
 * Funkcja wywolywana po zmienieniu zawartosci widgetu epw_subject_entry
 */
void on_epw_subject_entry_changed (GtkEditable *editable, gpointer user_data)
{
	GtkWidget *epw_add_btn = (gpointer) lookup_widget (GTK_WIDGET (epw_widget), "epw_add_btn");
	
	if ((pw_epw_select_hour >= 0) && (strlen (gtk_entry_get_text (GTK_ENTRY (editable))) > 0))
		gtk_widget_set_sensitive (GTK_WIDGET (epw_add_btn), TRUE);
	else
		gtk_widget_set_sensitive (GTK_WIDGET (epw_add_btn), FALSE);
}


/*
 * edit_plan_hour_window -> ephw_hour_entry
 * Funkcja wywolywana po zmienieniu zawartosci widgetu ephw_hour_entry
 */
void on_ephw_hour_entry_changed (GtkEditable *editable, gpointer user_data)
{
	GtkWidget *ephw_add_hour_btn = (gpointer) lookup_widget (GTK_WIDGET (ephw_widget), "ephw_add_hour_btn");
	
	if (strlen (gtk_entry_get_text (GTK_ENTRY (editable))) > 0)
		gtk_widget_set_sensitive (GTK_WIDGET (ephw_add_hour_btn), TRUE);
	else
		gtk_widget_set_sensitive (GTK_WIDGET (ephw_add_hour_btn), FALSE);
}


/*
 * main_window -> toolbar -> mw_tb_add_btn
 * Funkcja wywolywana po kliknieciu na przycisk mw_tb_add_btn
 */
void on_mw_tb_add_btn_clicked (GtkToolButton *toolbutton, gpointer user_data)
{
	mw_marks_clist_load_subjects (date_get_weekday (entry_date));
}


/*
 * main_window -> toolbar -> mw_tb_search_btn
 * Funkcja wywolywana po kliknieciu na przycisk mw_tb_search_btn
 */
void on_mw_tb_search_btn_clicked (GtkToolButton *toolbutton, gpointer user_data)
{
	on_search_tests_activate (NULL, NULL);
}


/*
 * main_window -> toolbar -> mw_tb_exit_btn
 * Funkcja wywolywana po kliknieciu na przycisk mw_tb_exit_btn
 */
void on_mw_tb_exit_btn_clicked (GtkToolButton *toolbutton, gpointer user_data)
{
	on_main_window_delete_event (NULL, NULL, NULL);
	gtk_main_quit();
}


/*
 * plan_window_msg_hours -> pwmh_ok_btn
 * Funkcja wywolywana po kliknieciu na przycisk OK
 */
void on_pwmh_ok_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (GTK_WIDGET (pwmh_widget));
	
	pw_widget = create_plan_window ();
	gtk_widget_show (GTK_WIDGET (pw_widget));
	
	ephw_widget = create_edit_plan_hours_window ();
	gtk_widget_show (GTK_WIDGET (ephw_widget));
}


/*
 * main_window_edit_subject -> mwes_cancel_tbn
 * Funkcja wywolywana po kliknieciu na przycisk anuluj
 */
void on_mwes_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (GTK_WIDGET (mwes_widget));
}


/*
 * main_window_edit_subject -> mwes_ok_tbn
 * Funkcja wywolywana po kliknieciu na przycisk OK
 */
void on_mwes_ok_btn_clicked (GtkButton *button, gpointer user_data)
{
	if (mw_marks_clist_rowselected > -1)
		mw_marks_clist_remove (mw_marks_clist_rowselected);
	
	mwes_marks_add ();
	gtk_widget_hide (GTK_WIDGET (mwes_widget));
}


/*
 * plan_window_msg_hours -> pwmh_cancel_btn
 * Funkcja wywolywana po kliknieciu na przycisk Anuluj
 */
void on_pwmh_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (GTK_WIDGET (pwmh_widget));
	
	pw_widget = create_plan_window ();
	gtudb_plan_num_hours (TRUE);
	pw_load_subjects ();
	pw_enable_buttons ();
	gtk_widget_show (GTK_WIDGET (pw_widget));
}


/*
 * main_window -> menu -> insert_subjects
 * Funkcja wywolywana po wybraniu z menu opcji wstaw przedmioty
 */
void on_insert_subjects_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	on_mw_tb_add_btn_clicked (NULL, NULL);
}


/*
 * main_window -> menu -> search_tests
 * Funkcja wywolywana po wybraniu z menu opcji szukaj sprawdzianow
 */
void on_search_tests_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	mwt_widget = create_main_window_tests ();
	mwt_show ();
}


/*
 * main_window -> menu -> clear_subjects
 * Funkcja wywolywana po wybraniu z menu opcji wyczysc przedmioty i oceny
 */
void on_clear_subjects_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	mw_marks_clist_clear  ();
	mw_tests_clist_clear  ();
	mw_quizes_clist_clear ();
}


/*
 * main_window -> menu -> clear_notes
 * Funkcja wywolywana po wybraniu z menu opcji wyczysc notatki
 */
void on_clear_notes_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	mw_notes_textview_set_text ("");
}


/*
 * main_window -> menu -> today
 * Funkcja wywolywana po wybraniu z menu opcji Dzisiejszy wpis
 */
void on_today_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	mw_edit_entry (date_today (), TRUE);
}


/*
 * main_window -> menu -> gnutu_www
 * Funkcja wywolywana po wybraniu z menu opcji Strona programu
 */
void on_gnutu_www_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	gnome_url_show ("http://www.gnutu.org/", NULL);
}


/*
 * main_window -> menu -> email
 * Funkcja wywolywana po wybraniu z menu opcji Zadaj pytanie
 */
void on_email_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	gnome_url_show ("mailto: mkk@gnutu.org&topic=GNUTU: Pytanie", NULL);
}


/*
 * main_window -> menu -> forum
 * Funkcja wywolywana po wybraniu z menu opcji Forum dyskusyjne
 */
void on_forum_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	gnome_url_show ("http://www.gnutu.org/?modul=forum", NULL);
}


/*
 * main_window -> menu -> donate
 * Funkcja wywolywana po wybraniu z menu opcji Wesprzyj projekt !
 */
void on_donate_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	gnome_url_show ("http://www.gnutu.org/?modul=teksty&id_txt=wesprzyj_projekt", NULL);
}


/*
 * diary_window -> dw_cancel_btn
 * Funkcja wywolywana po kliknieciu na przycisk dw_cancel_btn 
 */
void on_dw_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (GTK_WIDGET (dw_widget));
}


/*
 * diary_window -> dw_ok_btn
 * Funkcja wywolywana po kliknieciu na przycisk dw_ok_btn
 */
void on_dw_ok_btn_clicked (GtkButton *button, gpointer user_data)
{
	dw_save_entry (dw_entry_date);
	gtk_widget_hide (GTK_WIDGET (dw_widget));
}


/*
 * main_window -> menu -> diary
 * Funkcja wywolywana po wybraniu z menu opcji Dziennik
 */
void on_diary_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	dw_widget = create_diary_window ();
	
	dw_load_entry (entry_date);
	gtk_widget_show (GTK_WIDGET (dw_widget));
}


/*
 * diary_window -> dw_date_date_edit
 * Funkcja wywolywana po zmienieniu daty
 */
void on_dw_date_date_edit_date_changed (GnomeDateEdit *gnomedateedit, gpointer user_data)
{
	dw_save_entry (dw_entry_date);
	
	GtkWidget *dw_date_date_edit = lookup_widget (GTK_WIDGET (gnomedateedit), "dw_date_date_edit");
	dw_entry_date = timet_to_typedate (gnome_date_edit_get_time (GNOME_DATE_EDIT(dw_date_date_edit)));
	
	dw_load_entry (dw_entry_date);
}


/*
 * main_window_tests -> search_btn
 * Funkcja wywolywana po kliknieciu na przycisk search_btn
 */
void on_mwt_search_btn_clicked (GtkButton *button, gpointer user_data)
{
	mwt_search ();
}


/*
 * main_window_tests -> ok_btn
 * Funkcja wywolywana po kliknieciu na przycisk ok_btn
 */
void on_mwt_ok_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (GTK_WIDGET (mwt_widget));
}


/*
 * main_window -> menu -> make_backup
 * Funkcja wywolywana wybraniu z menu opcji stworz kopie zapasowa
 */
void on_make_backup_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	bw_widget = create_backup_window ();
	
	gchar      file_name[50];
	GtkWidget *bw_backup_file_entry = (gpointer) lookup_widget (GTK_WIDGET (bw_widget), "bw_backup_file_entry");
	
	sprintf (file_name, "~/gnutu-backup-%d-%d-%d", date_today ().day, date_today ().month, date_today ().year);
	gnome_file_entry_set_filename (GNOME_FILE_ENTRY (bw_backup_file_entry), file_name);
	
	gtk_widget_show (GTK_WIDGET (bw_widget));
}


/*
 * main_window -> menu -> backup_load
 * Funkcja wywolywana wybraniu z menu opcji wczytaj kopie zapasowa
 */
void on_backup_load_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	lbw_widget = create_load_backup_window ();
	gtk_widget_show (GTK_WIDGET (lbw_widget));
}


/*
 * backup_window -> bw_cancel_btn
 * Funkcja wywolywana po kliknieciu na przycik Anuluj
 */
void on_bw_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (GTK_WIDGET (bw_widget));
}


/*
 * backup_window -> bw_ok_btn
 * Funkcja wywolywana po kliknieciu na przycik Ok
 */
void on_bw_save_btn_clicked (GtkButton *button, gpointer user_data)
{
	bw_make_backup ();
	gtk_widget_hide (GTK_WIDGET (bw_widget));
}


/*
 * load_backup_window -> lbw_cancel_btn
 * Funkcja wywolywana po kliknieciu na przycik Anuluj
 */
void on_lbw_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (GTK_WIDGET (lbw_widget));
}


/*
 * load_backup_window -> lbw_ok_btn
 * Funkcja wywolywana po kliknieciu na przycik Ok
 */
void on_lbw_load_btn_clicked (GtkButton *button, gpointer user_data)
{
	bw_load_backup  ();
	gtk_widget_hide (GTK_WIDGET (lbw_widget));
}


/*
 * main_window -> menu -> settings
 * Funkcja wywolywana wybraniu z menu opcji Preferencje
 */
void on_settings_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	sw_widget = create_settings_window ();
	
	sw_read_general  ();
	sw_read_left_bar ();
	
	gtk_widget_show (GTK_WIDGET (sw_widget));
}


/*
 * settings_window -> sw_cancel_btn
 * Funkcja wywolywana po kliknieciu na przycik Anuluj
 */
void on_sw_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtudb_settings_read ();
	
	gtk_widget_hide (GTK_WIDGET (sw_widget));
}


/*
 * settings_window -> sw_ok_btn
 * Funkcja wywolywana po kliknieciu na przycik Ok
 */
void on_sw_ok_btn_clicked (GtkButton *button, gpointer user_data)
{
	sw_save_general  ();
	sw_save_left_bar ();
	gtudb_settings_write ();
	
	gtk_widget_hide (GTK_WIDGET (sw_widget));
}


/*
 * main_window -> menu -> free days
 * Funkcja wywolywana wybraniu z menu opcji Wolne dni
 */
void on_free_days_activate (GtkMenuItem *menuitem, gpointer user_data)
{
	fdw_widget = create_free_days_window ();
	
	fdw_free_days_clist_load ();
	gtk_widget_show (GTK_WIDGET (fdw_widget));
}


/*
 * free_days_window -> fdw_cancel_btn
 * Funkcja wywolywana po kliknieciu na przycisk Anuluj
 */
void on_fdw_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtudb_fd_read (); // ponownie wczytujemy baze (aby wprowadzone zmiany nie zostaly zapisane)
	gtk_widget_hide (GTK_WIDGET (fdw_widget));
}


/*
 * free_days_window -> fdw_ok_btn
 * Funkcja wywolywana po kliknieciu na przycisk OK
 */
void on_fdw_ok_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtudb_fd_write ();
	gtk_widget_hide (GTK_WIDGET (fdw_widget));
}


/*
 * free_days_window -> fdw_add_btn
 * Funkcja wywolywana po kliknieciu na przycisk Dodaj
 */
void on_fdw_add_btn_clicked (GtkButton *button, gpointer user_data)
{
	fdw_free_days_clist_rowselected = -1;
	
	efdw_widget = create_edit_free_days_window ();
	gtk_widget_show (GTK_WIDGET (efdw_widget));
}


/*
 * free_days_window -> fdw_mod_btn
 * Funkcja wywolywana po kliknieciu na przycisk Zmodyfikuj
 */
void on_fdw_mod_btn_clicked (GtkButton *button, gpointer user_data)
{
	efdw_widget = create_edit_free_days_window ();
	
	efdw_edit_day ();
	gtk_widget_show (GTK_WIDGET (efdw_widget));
}


/*
 * free_days_window -> fdw_remove_btn
 * Funkcja wywolywana po kliknieciu na przycisk Usuń
 */
void on_fdw_remove_btn_clicked (GtkButton *button, gpointer user_data)
{
	fdw_remove_free_day (fdw_free_days_clist_rowselected);
}


void on_efdw_cancel_btn_clicked (GtkButton *button, gpointer user_data)
{
	gtk_widget_hide (GTK_WIDGET (efdw_widget));
}


void on_efdw_ok_btn_clicked (GtkButton *button, gpointer user_data)
{
	if (fdw_free_days_clist_rowselected != -1)
		fdw_remove_free_day (fdw_free_days_clist_rowselected);
	
	efdw_add_free_day ();
	gtk_widget_hide (GTK_WIDGET (efdw_widget));
}


void on_fdw_free_days_clist_select_row (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer user_data)
{
	GtkWidget *fdw_mod_btn    = (gpointer) lookup_widget (GTK_WIDGET (fdw_widget), "fdw_mod_btn");
	GtkWidget *fdw_remove_btn = (gpointer) lookup_widget (GTK_WIDGET (fdw_widget), "fdw_remove_btn");
	
	gtk_widget_set_sensitive (GTK_WIDGET (fdw_mod_btn), TRUE);
	gtk_widget_set_sensitive (GTK_WIDGET (fdw_remove_btn), TRUE);
	
	fdw_free_days_clist_rowselected = row;
}


void on_fdw_free_days_clist_unselect_row (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer user_data)
{
	GtkWidget *fdw_mod_btn    = (gpointer) lookup_widget (GTK_WIDGET (fdw_widget), "fdw_mod_btn");
	GtkWidget *fdw_remove_btn = (gpointer) lookup_widget (GTK_WIDGET (fdw_widget), "fdw_remove_btn");
	
	gtk_widget_set_sensitive (GTK_WIDGET (fdw_mod_btn), FALSE);
	gtk_widget_set_sensitive (GTK_WIDGET (fdw_remove_btn), FALSE);
	
	fdw_free_days_clist_rowselected = -1;
}


/*
 * edit_plan_hours_window -> ephw_hour_entry
 * Funkcja wywolywana wcisnieciu dowolnego klawisza w widgecie 'ephw_hour_entry'
 */
gboolean on_ephw_hour_entry_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
{
	if (event->keyval == GDK_Return) // jesli tym klawiszem jest ENTER to dodajemy nowa godzine
		on_ephw_add_hour_btn_clicked (NULL, NULL);
	
	return FALSE;
}


/*
 * edit_plan_window -> epw_subject_entry
 * Funkcja wywolywana wcisnieciu dowolnego klawisza w widgecie 'ephw_hour_entry'
 */
gboolean on_epw_subject_entry_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
{
	if (event->keyval == GDK_Return) // jesli tym klawiszem jest ENTER to dodajemy nowa godzine
		on_epw_add_btn_clicked (NULL, NULL);
	
	return FALSE;
}


/*
 * edit_plan_hours_window -> ephw_hour_entry
 * Funkcja wywolywana wcisnieciu dowolnego klawisza w widgecie 'ephw_hour_entry'
 */
gboolean on_efdw_desc_entry_key_release_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
{
	if (event->keyval == GDK_Return) // jesli tym klawiszem jest ENTER to dodajemy nowa godzine
		on_efdw_ok_btn_clicked (NULL, NULL);
	
	return FALSE;
}


/*
 * Funkcja blokuje zamkniecie okna importu bazy danych
 */
gboolean on_import_db_window_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	return TRUE;
}
