/***************************************************************************
 *            mw.c
 *
 *  Sat Sep  4 21:28:07 2004
 *  Copyright  2004  Marcin K. Krzywonos
 *  mkk@gnutu.org
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#include <pwd.h>

#include "var.h"
#include "mw.h"
#include "gtudb.h"


/*
 * Funkcja wykonuje operacje przy pokazaniu okna main_window
 */
int mw_show (GtkWidget *widget)
{
	// Widget okna glownego
	mw_widget = widget;
	
	// Wczytujemy bazy danych
	if (gtudb_read () == 1)
		idbw_show ();
	
	if (gtudb_settings_read () == 1)
		sw_default_settings ();
	
	gtudb_plan_read ();
	gtudb_fd_read ();
	
	// Wczytujemy wpis
	mw_get_entry_date ();
	mw_edit_entry (entry_date, FALSE);
	
	// Powitanie
	printf (_("--------------------\nGNU Terminarz Ucznia\n   www.gnutu.org\n--------------------\n\n"));
}


/*
 * Funkcja wczytuje wpis
 * Parametry:
 *            - date - data wczytywanego wpisu
 *            - save - okresla czy poprzedni wpis powinien byc zapisany
 */
int mw_edit_entry (type_date date, gboolean save)
{
	GSList       *tmp_db, *tmp_db_2; // Listy
	GTUDBEntry   *tmp_entry;         // Zmienne przechowujace wpis
	GTUDBSubject *tmp_sub;
	int           sub_cnt   = 0;     // Licznik
	
	if (save == TRUE) {
		// Odczytujemy dane biezacego wpisu do zmiennej r_entry
		GTUDBEntry *r_entry   = g_new (GTUDBEntry, 1);
		
		r_entry->subjects = mw_marks_clist_get_marks   ();
		r_entry->notes    = mw_notes_textview_get_text ();
		r_entry->date     = entry_date;
		
		// Usuwamy element listy o numerze aktualnie wczytanego wpisu
		GSList *temp_ery = g_slist_nth (gtudb_list, gtudb_search_entry (entry_date));
		gtudb_list = g_slist_remove_link (gtudb_list, temp_ery);
		
		// Dodajemy nowy element
		gtudb_list = g_slist_append (gtudb_list, r_entry);
	}
	
	// Numer wczytywanego wpisu (o ile istnieje)
	int entry_cnt = gtudb_search_entry (date);
	
	if (entry_cnt == -1) { // Jesli nie istnieje to tworzymy nowy, pusty wpis
		mw_clear_all ();
		
		// automatyczne wstawianie przedmiotow
		if (strcmp (gtudb_settings_get_value ("insert_subjects"), "TRUE") == 0) {
			// sprawdzamy czy wybrana data nie "znajduje" sie na wakacjach
			if ((g_date_compare (text_to_gdate (gtudb_settings_get_value ("school_year_end")),
								type_date_to_gdate (date)) > 0) &&
			   (g_date_compare (text_to_gdate (gtudb_settings_get_value ("vacation_end")),
								type_date_to_gdate (date)) > 0))
			{
				if (gtudb_fd_search_day (date) == -1) // sprawdzamy czy data jest wolnym dniem
					mw_marks_clist_load_subjects (date_get_weekday (date));
			}
		}
	} else { // W przeciwnym wypadku wczytujemy stary wpis
		// Pobieramy wpis z listy
		tmp_db    = g_slist_nth (gtudb_list, entry_cnt);
		tmp_entry = tmp_db->data;
		
		// Czyscimy zawartosc wszystkich pol wpisu
		mw_clear_all ();
		
		// Wypelniamy pola wpisu
		mw_notes_textview_set_text (tmp_entry->notes);
		
		while (sub_cnt < g_slist_length (tmp_entry->subjects)) {
			tmp_db_2 = g_slist_nth (tmp_entry->subjects, sub_cnt);
			tmp_sub  = tmp_db_2->data;
			
			mw_marks_clist_add (tmp_sub->time, tmp_sub->name, tmp_sub->marks);
			
			if (tmp_sub->flag == 1)
				mw_quizes_clist_add (tmp_sub->name);
			
			if (tmp_sub->flag == 2)
				mw_tests_clist_add (tmp_sub->name);
			
			sub_cnt++;
		}
	}
	
	// Ustawiamy biezaca date na date wczytanego lub utworzonego nowego wpisu
	entry_date = date;
	
	// pozostale informacje
	mw_date_label_set_date (entry_date);
	mw_info_label_set_info ();
}


/*
 * Funkcja zapisuje w zmiennej 'entry_date' date biezacego wpisu
 */
int mw_get_entry_date ()
{
	GtkWidget *calendar = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_calendar");
	gtk_calendar_get_date (GTK_CALENDAR (calendar), &entry_date.year, &entry_date.month, &entry_date.day);
	
	entry_date.month++;
}


/*
 * Funkcja ustawia date w etykiecie mw_date_label_set_date
 */
int mw_date_label_set_date (type_date date)
{
	GtkWidget *mw_date_label = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_date_label");
	
	gchar tmp[100];
	sprintf (tmp, _("<b>Data: </b>%d-%d-%d"), date.day, date.month, date.year);
	
	gtk_label_set_label (GTK_LABEL (mw_date_label), tmp);
	
	return 0;
}


/*
 * Funkcja wyswietla informacje o wpisie w etykiecie mw_info_label
 */
int mw_info_label_set_info ()
{
	GtkWidget *mw_info_label = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_info_label");
	gchar      tmp_txt[2048];
	strcpy (tmp_txt, "");
	
	if (strcmp (gtudb_settings_get_value ("show_info_about_day"), "TRUE") == 0)
		strcat (tmp_txt, mw_info_day ());
	
	if (strcmp (gtudb_settings_get_value ("show_new_tests"), "TRUE") == 0)
		strcat (tmp_txt, mw_info_search_test ());
	
	if (strcmp (gtudb_settings_get_value ("show_days_counter"), "TRUE") == 0)
		strcat (tmp_txt, mw_info_days_cnt ());
	
	gtk_label_set_label (GTK_LABEL (mw_info_label), tmp_txt);
	
	return 0;
}


/*
 * Funkcja zwraca informacje o najblizszych sprawdzianach (tylko ze jednego
 * dnia). Dane sa przygotowane dla dla "mw_info_label"
 */
gchar *mw_info_search_test ()
{
	gchar rtn[2048];
	sprintf (rtn, "");
	
	GDate *end_date = type_date_to_gdate (entry_date);
	g_date_add_days (end_date, atoi (gtudb_settings_get_value ("show_new_tests_days")));
	
	if (g_slist_length (gtudb_search_test (entry_date, gdate_to_type_date (end_date))) > 0) {
		type_date date_tmp = gdate_to_type_date (text_to_gdate (g_strdup (g_slist_nth (gtudb_search_test (entry_date, gdate_to_type_date (end_date)), 0)->data)));
		sprintf (rtn, _("<b>Najblizsze sprawdziany:\n%d-%d-%d</b>\n"), date_tmp.day, date_tmp.month, date_tmp.year);
		
		GSList *tmp2 = gtudb_entry_get_subjects_list (date_tmp, 2);
		int j    = 0;
		while (j < g_slist_length (tmp2)) {
			sprintf (rtn, _("%s\t%s\n"), rtn, g_strdup (g_slist_nth (tmp2, j)->data));
			j++;
		}
		
		tmp2 = gtudb_entry_get_subjects_list (date_tmp, 1);
		j    = 0;
		while (j < g_slist_length (tmp2)) {
			sprintf (rtn, _("%s\t%s\n"), rtn, g_strdup (g_slist_nth (tmp2, j)->data));
			j++;
		}
	}
	
	return g_strdup ((gchar *) rtn);
}


/*
 * Funkcja zwraca informacje o ilosci dni pozostalych do konca roku szkolnego.
 * Dane sa przygotowane dla dla "mw_info_label"
 */
gchar *mw_info_days_cnt ()
{
	gchar rtn[2048];
	
	if (date_diff (entry_date, gdate_to_type_date (text_to_gdate (gtudb_settings_get_value ("school_year_end")))) <= 0) {
		if (date_diff (entry_date, gdate_to_type_date (text_to_gdate (gtudb_settings_get_value ("vacation_end")))) > 0)
			sprintf (rtn, _("\n<b>Do konca wakacji\npozostalo dni: </b>%d\n"), date_diff (entry_date, gdate_to_type_date (text_to_gdate (gtudb_settings_get_value ("vacation_end")))));
	} else {
		sprintf (rtn, _("\n<b>Do konca roku szkolnego\npozostalo dni: </b>%d\n"), date_diff (entry_date, gdate_to_type_date (text_to_gdate (gtudb_settings_get_value ("school_year_end")))));
	}
	
	return g_strdup ((gchar *) rtn);
}


/*
 * Funkcja zwraca informacje o danym dniu (wg. wolnych dni).
 * Dane sa przygotowane dla dla "mw_info_label"
 */
gchar *mw_info_day ()
{
	gchar rtn[2048];
	
	if (gtudb_fd_search_day (entry_date) == -1)
		return "";
	
	GTUDBFreeDays *tmp_entry = tmp_entry = g_slist_nth (gtudb_fd_list, gtudb_fd_search_day (entry_date))->data;
	
	if (strlen (tmp_entry->desc) < 1)
		return "";
	
	strcpy (rtn, "<b>");
	strcat (rtn, g_strdup (tmp_entry->desc));
	strcat (rtn, "</b>\n\n");
	
	return g_strdup ((gchar *) rtn);
}


/* Funkcja dodaje nowa pozycje do listy przedmiotow i ocen
 * Parametry:
 *           - time    - godzina rozpoczecia lekcji
 *           - subject - nazwa przedmiotu
 *           - marks   - oceny
 */
int mw_marks_clist_add (gchar *time, gchar *subject, gchar *marks)
{
	if (strlen (subject) == 0)
		return 1;
	
	gchar *tmp_time;
	if (time [1] == ':') {
		sprintf (tmp_time, "0%s", time);
		time = tmp_time;
	}
	
	GtkWidget *mw_marks_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_marks_clist");
	
	gchar *mw_tmp [] = {time, subject, marks};
	gtk_clist_insert (GTK_CLIST (mw_marks_clist), 0, mw_tmp);
	
	gtk_clist_sort (GTK_CLIST (mw_marks_clist));
	
	return 0;
}



/*
 * Funkcja usuwa pozycje o numerze id z listy przedmiotow i ocen
 */
int mw_marks_clist_remove (int id)
{
	GtkWidget *mw_marks_clist  = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_marks_clist");
	
	gchar *tmp;
	gtk_clist_get_text (GTK_CLIST (mw_marks_clist), id, 1, &tmp);
	
	mw_tests_clist_remove_test (tmp);
	mw_tests_clist_remove_quiz (tmp);
	gtk_clist_remove (GTK_CLIST (mw_marks_clist), id);
}


/*
 * Funkcja czysci zawartosc listy przedmiotow i ocen*
 */
int mw_marks_clist_clear ()
{
	GtkWidget *mw_marks_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_marks_clist");
	gtk_clist_clear (GTK_CLIST (mw_marks_clist));
}


/*
 * Funkcja pobiera i zwraca zawartosc pola przedmiotow i ocen
 */
GSList *mw_marks_clist_get_marks ()
{
	GtkWidget    *mw_marks_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_marks_clist");
	GSList       *list           = NULL;
	GTUDBSubject *subject        = g_new (GTUDBSubject, 1);
	
	int    i = 0;
	gchar *tmp;
	
	while (gtk_clist_get_text (GTK_CLIST (mw_marks_clist), i, 1, &tmp) == 1) {
		subject->name = g_strdup (tmp);
		
		gtk_clist_get_text (GTK_CLIST (mw_marks_clist), i, 0, &tmp);
		subject->time = g_strdup (tmp);
		
		gtk_clist_get_text (GTK_CLIST (mw_marks_clist), i, 2, &tmp);
		subject->marks = g_strdup (tmp);
		
		if (mw_tests_clist_check_test (subject->name) == 1) {
			subject->flag = 2;
		} else {
			if (mw_quizes_clist_check_quiz (subject->name) == 1)
				subject->flag = 1;
			else
				subject->flag = 0;
		}
		
		list = g_slist_append (list, subject);
		
		subject = g_new (GTUDBSubject, 1);
		i++;
	}
	
	return list;
}


/*
 * Funkcja wczytuje z planu lekcji do tabeli "mw_marks_clist" przedmioty
 * odpowiadajace dniu podanemu jako parametr day
 */
int mw_marks_clist_load_subjects (int day)
{
	if (day == 7)
		return 0;
	
	mw_marks_clist_clear ();
	
	int i = 0;
	while ((i < g_slist_length (gtudb_plan_list [0])) && (i < g_slist_length (gtudb_plan_list [day]))) {
		mw_marks_clist_add (g_strdup (g_slist_nth (gtudb_plan_list[0], i)->data),
							g_strdup (g_slist_nth (gtudb_plan_list[day], i)->data), "");
		
		i++;
	}
	
	return 0;
}


/*
 * Funkcja wczytuje z listy przedmiotow i ocen do pol wpisu przedmiotow i ocen
 * linie o numerze zapisanym w zmiennej "row"
 */
int mwes_marks_edit (int row)
{
	gchar *time, *subject, *marks;
	
	GtkWidget *mw_marks_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_marks_clist");
	gtk_clist_get_text (GTK_CLIST (mw_marks_clist), row, 0, &time);
	gtk_clist_get_text (GTK_CLIST (mw_marks_clist), row, 1, &subject);
	gtk_clist_get_text (GTK_CLIST (mw_marks_clist), row, 2, &marks);
	
	
	GtkWidget *mwes_subject_flag_1 = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_subject_flag_1");
	GtkWidget *mwes_subject_flag_2 = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_subject_flag_2");
	GtkWidget *mwes_subject_flag_3 = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_subject_flag_3");
	
	if (mw_tests_clist_check_test (subject) == 1) {
		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mwes_subject_flag_1), TRUE);
	} else {
		if (mw_quizes_clist_check_quiz (subject) == 1)
			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mwes_subject_flag_2), TRUE);
		else
			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mwes_subject_flag_3), TRUE);
	}
	
	GtkWidget *mwes_marks_time_entry = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_marks_time_entry");
	gtk_entry_set_text (GTK_ENTRY (mwes_marks_time_entry), time);
	
	GtkWidget *mwes_marks_subject_entry = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_marks_subject_entry");
	gtk_entry_set_text (GTK_ENTRY (mwes_marks_subject_entry), subject);
	
	GtkWidget *mwes_marks_marks_entry = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_marks_marks_entry");
	gtk_entry_set_text (GTK_ENTRY (mwes_marks_marks_entry), marks);
}


/*
 * Funkcja pobiera dane z pol wpisu przedmiotow i ocen i dodaje do listy
 */
int mwes_marks_add ()
{
	// Zmienne, itp...
	gchar *time, *subject, *marks;
	
	GtkWidget *mwes_subject_flag_1 = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_subject_flag_1");
	GtkWidget *mwes_subject_flag_2 = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_subject_flag_2");
	GtkWidget *mwes_marks_time_entry = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_marks_time_entry");
	GtkWidget *mwes_marks_subject_entry = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_marks_subject_entry");
	GtkWidget *mwes_marks_marks_entry = (gpointer) lookup_widget (GTK_WIDGET (mwes_widget), "mwes_marks_marks_entry");
	
	
	// Odczytujemy dane
	time    = (gchar *) gtk_entry_get_text (GTK_ENTRY (mwes_marks_time_entry));
	subject = (gchar *) gtk_entry_get_text (GTK_ENTRY (mwes_marks_subject_entry));
	marks   = (gchar *) gtk_entry_get_text (GTK_ENTRY (mwes_marks_marks_entry));
	
	
	// Uzupelniamy pola...
	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (mwes_subject_flag_1)) == TRUE) {
		mw_tests_clist_add (subject);
	} else {
		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (mwes_subject_flag_2)) == TRUE)
			mw_quizes_clist_add (subject);
	}
	
	mw_marks_clist_add (time, subject, marks);
	
	return 0;
}


/* Funkcja dodaje nowa pozycje do listy sprawdzianow
 * parametry:
 *            - gubject - nazwa_przedmiotu
 */
int mw_tests_clist_add (gchar *subject)
{
	if (strlen (subject) == 0)
		return 1;
	
	GtkWidget *mw_tests_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_tests_clist");
	
	gchar *mw_tmp [] = {subject};
	
	gtk_clist_insert (GTK_CLIST (mw_tests_clist), 0, mw_tmp);
	
	return 0;
}


/*
 * Czysci zawartosc listy klasowek
 */
int mw_tests_clist_clear ()
{
	GtkWidget *mw_tests_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_tests_clist");
	gtk_clist_clear (GTK_CLIST (mw_tests_clist));
}


/*
 * Czysci zawartosc listy (widgetu) z wpisami
 */
int mw_tests_clist_check_test (gchar *name)
{
	GtkWidget *mw_tests_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_tests_clist");
	gchar     *test;
	
	int i = 0;
	while (gtk_clist_get_text (GTK_CLIST (mw_tests_clist), i, 0, &test) == 1) {
		if (strcmp (name, test) == 0)
			return 1;
		
		i++;
	}
	
	return 0;
}


/*
 * Usuwa z listy mw_tests_clist, sprawdzian o nazwie "name"
 */
int mw_tests_clist_remove_test (gchar *name)
{
	GtkWidget *mw_tests_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_tests_clist");
	gchar     *test;
	
	int i = 0;
	while (gtk_clist_get_text (GTK_CLIST (mw_tests_clist), i, 0, &test) == 1) {
		if (strcmp (name, test) == 0) {
			gtk_clist_remove (GTK_CLIST (mw_tests_clist), i);
			return 1;
		}
		
		i++;
	}
	
	return 0;
}


/*
 * Funkcja dodaje nowa pozycje do listy kartkowek
 * parametry:
 *            - gubject - nazwa_przedmiotu
 */
int mw_quizes_clist_add (gchar *subject)
{
	if (strlen (subject) == 0)
		return 1;
	
	GtkWidget *mw_quizes_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_quizes_clist");
	
	gchar *mw_tmp [] = {subject};
	
	gtk_clist_insert (GTK_CLIST (mw_quizes_clist), 0, mw_tmp);
	
	return 0;
}


/*
 * Funkcja czysci zawartosc listy kartkowek
 */
int mw_quizes_clist_clear ()
{
	GtkWidget *mw_quizes_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_quizes_clist");
	gtk_clist_clear (GTK_CLIST (mw_quizes_clist));
}


/*
 * Funkcja sprawdza czy kartkowka o nazwa zawartej w zmiennej "name" znajduje
 * sie na liscie kartkowek (mw_quizes_clist)
 */
int mw_quizes_clist_check_quiz (gchar *name)
{
	GtkWidget *mw_quizes_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_quizes_clist");
	gchar     *test;
	
	int i = 0;
	while (gtk_clist_get_text (GTK_CLIST (mw_quizes_clist), i, 0, &test) == 1) {
		if (strcmp (name, test) == 0)
			return 1;
		
		i++;
	}
	
	return 0;
}


/*
 * Usuwa z listy mw_quizes_clist, kartkowke o nazwie "name"
 */
int mw_tests_clist_remove_quiz (gchar *name)
{
	GtkWidget *mw_quizes_clist = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_quizes_clist");
	gchar     *test;
	
	int i = 0;
	while (gtk_clist_get_text (GTK_CLIST (mw_quizes_clist), i, 0, &test) == 1) {
		if (strcmp (name, test) == 0) {
			gtk_clist_remove (GTK_CLIST (mw_quizes_clist), i);
			return 1;
		}
		
		i++;
	}
	
	return 0;
}


/*
 * Funkcja pobiera i zwraca zawartosc pola notatek
 */
gchar *mw_notes_textview_get_text ()
{
	GtkWidget     *mw_notes_textview = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_notes_textview");
	GtkTextIter    start, end;
	GtkTextBuffer *text_buffer    = gtk_text_view_get_buffer (GTK_TEXT_VIEW (mw_notes_textview));
	
	gtk_text_buffer_get_bounds (text_buffer, &start, &end);
	
	return gtk_text_buffer_get_text (text_buffer, &start, &end, TRUE);
}


/*
 * Funkcja zmienia zawartosc pola notatek
 * parametry:
 *            - text - tekst wstawiany do pola notatek
 */
int mw_notes_textview_set_text (gchar *text)
{
	GtkWidget     *mw_notes_textview = (gpointer) lookup_widget (GTK_WIDGET (mw_widget), "mw_notes_textview");
	GtkTextBuffer *text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (mw_notes_textview));
	gtk_text_buffer_set_text (text_buffer, text, strlen (text));
}


/*
 * Funkcja czysci wszystkie pola wpisu (notatki, klasowki, przedmioty i oceny)
 */
int mw_clear_all ()
{
	mw_marks_clist_clear  ();
	mw_tests_clist_clear  ();
	mw_quizes_clist_clear ();
	
	mw_notes_textview_set_text ("");
}


/*
 * Funkcja pokazuje okno main_window_tests
 */
int mwt_show ()
{
	gtk_widget_show (GTK_WIDGET (mwt_widget));
	
	GtkWidget *mwt_from_date_edit = (gpointer) lookup_widget (GTK_WIDGET (mwt_widget), "mwt_from_date_edit");
	GtkWidget *mwt_to_date_edit   = (gpointer) lookup_widget (GTK_WIDGET (mwt_widget), "mwt_to_date_edit");
	
	GDate *date_end = type_date_to_gdate (entry_date);
	g_date_add_days (date_end, 30);
	
	gnome_date_edit_set_time (GNOME_DATE_EDIT (mwt_from_date_edit), typedate_to_timet (entry_date));
	gnome_date_edit_set_time (GNOME_DATE_EDIT (mwt_to_date_edit), typedate_to_timet (gdate_to_type_date(date_end)));
}


/*
 * Funkcja wyszukuje sprawdziany i wyswietla wyniki
 */
int mwt_search ()
{
	GtkWidget *mwt_from_date_edit = (gpointer) lookup_widget (GTK_WIDGET (mwt_widget), "mwt_from_date_edit");
	GtkWidget *mwt_to_date_edit   = (gpointer) lookup_widget (GTK_WIDGET (mwt_widget), "mwt_to_date_edit");
	GtkWidget *mwt_tests_label    = (gpointer) lookup_widget (GTK_WIDGET (mwt_widget), "mwt_tests_label");
	
	gtk_label_set_label (GTK_LABEL (mwt_tests_label), "");
	
	time_t date_begin = gnome_date_edit_get_time (GNOME_DATE_EDIT (mwt_from_date_edit));
	time_t date_end   = gnome_date_edit_get_time (GNOME_DATE_EDIT (mwt_to_date_edit));
	
	GSList *tmp = gtudb_search_test (timet_to_typedate (date_begin), timet_to_typedate (date_end));
	int     i   = 0;
	int     j   = 0;
	gchar   str[2048];
	
	sprintf (str, "");
	
	while (i < g_slist_length (tmp)) {
		sprintf (str, "%s<b>%s</b>\n", str, g_strdup (g_slist_nth (tmp, i)->data));
		
		GSList *tmp2 = gtudb_entry_get_subjects_list (gdate_to_type_date (text_to_gdate (g_strdup (g_slist_nth (tmp, i)->data))), 2);		

		j = 0;
		while (j < g_slist_length (tmp2)) {
			sprintf (str, _("%s\t%s (sprawdzian)\n"), str, g_strdup (g_slist_nth (tmp2, j)->data));
			j++;
		}
		
		tmp2 = gtudb_entry_get_subjects_list (gdate_to_type_date (text_to_gdate (g_strdup (g_slist_nth (tmp, i)->data))), 1);
		
		j = 0;
		while (j < g_slist_length (tmp2)) {
			sprintf (str, _("%s\t%s (kartkowka)\n"), str, g_strdup (g_slist_nth (tmp2, j)->data));
			j++;
		}
		
		sprintf (str, "%s\n", str);
		
		i++;
	}
	
	if (strlen (str) == 0)
		sprintf (str, _("<b>Nie znaleziono sprawdzianow !</b>\n"));
	
	gtk_label_set_label (GTK_LABEL (mwt_tests_label), str);
}
