/***************************************************************************
 *            var.c
 *
 *  Fri Sep  3 19:55:04 2004
 *  Copyright  2004  Marcin K. Krzywonos
 *  mkk@gnutu.org
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#include <time.h>
#include "var.h"


/*
 * Funkcja zamienia date w formacie time_t do daty w formacie type_date
 */
type_date timet_to_typedate (time_t date)
{
	type_date   tmp;
	struct tm *tstruct;
	
	tstruct   = localtime (&date);
	tmp.day   = tstruct->tm_mday;
	tmp.month = tstruct->tm_mon;
	tmp.year  = tstruct->tm_year;
	
	tmp.month++;
	tmp.year += 1900;
	
	return tmp;
}


/*
 * Funkcja zamienia date w formacie type_date do daty w formacie time_t
 */
time_t typedate_to_timet (type_date date)
{
	time_t     tmp;
	struct tm *tstruct;
	
	tstruct   = localtime (&tmp);
	
	tstruct->tm_mday = date.day;
	tstruct->tm_mon  = (date.month - 1);
	tstruct->tm_year = (date.year - 1900);
	
	return mktime (tstruct);
}


/*
 * Funkcja zwraca "dzisiejsza" date
 */
type_date date_today ()
{
	time_t     date_tmp = time (NULL);
	type_date  tmp;
	struct tm *tstruct;
	
	tstruct     = localtime (&date_tmp);
	tmp.day     = tstruct->tm_mday;
	tmp.month   = tstruct->tm_mon;
	tmp.year    = tstruct->tm_year;
	
	tmp.month++;
	tmp.year += 1900;
	
	return tmp;
}


/*
 * Funkcja konwertuje date z formatu type_date do formatu GDate.
 */
GDate *type_date_to_gdate (type_date date)
{
	GDate *rtn = g_date_new ();
	
	g_date_set_day   (rtn, date.day);
	g_date_set_month (rtn, date.month);
	g_date_set_year  (rtn, date.year);
	
	return rtn;
}


/*
 * Funkcja konwertuje date z formatu GDate do formatu type_date
 */
type_date  gdate_to_type_date (GDate *date)
{
	type_date rtn;
	
	rtn.day   = g_date_get_day   (date);
	rtn.month = g_date_get_month (date);
	rtn.year  = g_date_get_year  (date);
	
	return rtn;
}


/*
 * Funkcja konwertuje date w formacie tekstowym na format GDate
 */
GDate *text_to_gdate (gchar *text)
{
	GDate *rtn = g_date_new ();
	int    d, m, y;
	
	sscanf (text, "%d-%d-%d", &d, &m, &y);
	
	g_date_set_day   (rtn, d);
	g_date_set_month (rtn, m);
	g_date_set_year  (rtn, y);
	
	return rtn;
}


/*
 * Funkcja zwraca numer dnia tygodnia z podanej daty (zmienna "date")
 */
int date_get_weekday (type_date date)
{
	GDate *tmp_date = type_date_to_gdate (date);
	return g_date_get_weekday (tmp_date);
}


/*
 * Funkcja porownuje 2 daty i zwraca ich roznice (w dniach)
 * Parametry:
 *            - date_1 - data 1
 *            - date_2 - data 2
 */
int date_diff (type_date date_1, type_date date_2)
{
	GDate *gdate_1 = type_date_to_gdate (date_1);
	GDate *gdate_2 = type_date_to_gdate (date_2);
	
	return g_date_days_between (gdate_1, gdate_2);
}


/*
 * Funkcja porownuje 2 daty (zapisane w formacie tekstowym)
 */
gint date_compare (gconstpointer a, gconstpointer b)
{
	return g_date_compare (text_to_gdate ((gchar *) a), text_to_gdate ((gchar *) b));
}


/*
 * Funkcja zwraca pelna sciezke do pliku 'file_name' (w katalogu .gnutu)
 */
gchar *gtu_file_name (gchar *file_name)
{
	gchar rtn [1024];
	g_sprintf (rtn, "%s/.gnutu/%s", g_get_home_dir(), file_name);
	
	return g_strdup ((gchar *) rtn);
}
